.. :changelog:

History
========

1.0 (2013-10-19)
------------------

* Testing for Python 3.3, 2.7 and 2.6 Compatibility.
* Removed buildout.
* Re-Based on Cookiecutter.
* Sphinx for docs, added more examples.

0.2.1 (2009-05-18)
--------------------

* Forgot CHANGELOG.rst in MANIFEST.in.

0.2 (2009-05-17)
--------------------

* Added template filter `add_direction`.
* Removed `README`, add MAINFEST.in which includes `README.rst`.

0.1 (2009-04-28)
--------------------

* Initial release, context processors.
